Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Vault ¶
type Vault struct {
// contains filtered or unexported fields
}
Vault represent an entity which stores key value pair.
func File ¶
File takes in an encodingKey and filepath. This encryption key is then used in subsequent calls via Set and Get methods.
Click to show internal directories.
Click to hide internal directories.